from .codes import (
    red_darker,
    red_dark,
    red,
    red_light,
    red_lighter,
    pink_darker,
    pink_dark,
    pink,
    pink_light,
    pink_lighter,
    purple_darker,
    purple_dark,
    purple,
    purple_light,
    purple_lighter,
    deep_purple_darker,
    deep_purple_dark,
    deep_purple,
    deep_purple_light,
    deep_purple_lighter,
    indigo_darker,
    indigo_dark,
    indigo,
    indigo_light,
    indigo_lighter,
    blue_darker,
    blue_dark,
    blue,
    blue_light,
    blue_lighter,
    light_blue_darker,
    light_blue_dark,
    light_blue,
    light_blue_light,
    light_blue_lighter,
    cyan_darker,
    cyan_dark,
    cyan,
    cyan_light,
    cyan_lighter,
    teal_darker,
    teal_dark,
    teal,
    teal_light,
    teal_lighter,
    green_darker,
    green_dark,
    green,
    green_light,
    green_lighter,
    light_green_darker,
    light_green_dark,
    light_green,
    light_green_light,
    light_green_lighter,
    lime_darker,
    lime_dark,
    lime,
    lime_light,
    lime_lighter,
    yellow_darker,
    yellow_dark,
    yellow,
    yellow_light,
    yellow_lighter,
    amber_darker,
    amber_dark,
    amber,
    amber_light,
    amber_lighter,
    orange_darker,
    orange_dark,
    orange,
    orange_light,
    orange_lighter,
    salmon_darker,
    salmon_dark,
    salmon,
    salmon_light,
    salmon_lighter,
    brown_darker,
    brown_dark,
    brown,
    brown_light,
    brown_lighter,
    grey_darker,
    grey_dark,
    grey,
    grey_light,
    grey_lighter,
    blue_grey_darker,
    blue_grey_dark,
    blue_grey,
    blue_grey_light,
    blue_grey_lighter,
    black,
    white,
)

colors = dict(
    red_darker = red_darker,
    red_dark = red_dark,
    red = red ,
    red_light = red_light ,
    red_lighter = red_lighter,
    pink_darker = pink_darker,
    pink_dark = pink_dark ,
    pink = pink,
    pink_light = pink_light,
    pink_lighter = pink_lighter,
    purple_darker = purple_darker,
    purple_dark = purple_dark,
    purple = purple,
    purple_light = purple_light,
    purple_lighter = purple_lighter,
    deep_purple_darker = deep_purple_darker,
    deep_purple_dark = deep_purple_dark,
    deep_purple = deep_purple,
    deep_purple_light = deep_purple_light ,
    deep_purple_lighter = deep_purple_lighter ,
    indigo_darker = indigo_darker,
    indigo_dark = indigo_dark,
    indigo = indigo,
    indigo_light = indigo_light,
    indigo_lighter = indigo_lighter,
    blue_darker = blue_darker,
    blue_dark = blue_dark ,
    blue = blue,
    blue_light = blue_light,
    blue_lighter = blue_lighter,
    light_blue_darker = light_blue_darker ,
    light_blue_dark = light_blue_dark ,
    light_blue = light_blue,
    light_blue_light = light_blue_light,
    light_blue_lighter = light_blue_lighter,
    cyan_darker = cyan_darker,
    cyan_dark = cyan_dark ,
    cyan = cyan,
    cyan_light = cyan_light,
    cyan_lighter = cyan_lighter,
    teal_darker = teal_darker,
    teal_dark = teal_dark ,
    teal = teal,
    teal_light = teal_light,
    teal_lighter = teal_lighter,
    green_darker = green_darker,
    green_dark = green_dark,
    green = green ,
    green_light = green_light,
    green_lighter = green_lighter,
    light_green_darker = light_green_darker,
    light_green_dark = light_green_dark,
    light_green = light_green,
    light_green_light = light_green_light ,
    light_green_lighter = light_green_lighter ,
    lime_darker = lime_darker,
    lime_dark = lime_dark ,
    lime = lime,
    lime_light = lime_light,
    lime_lighter = lime_lighter,
    yellow_darker = yellow_darker,
    yellow_dark = yellow_dark,
    yellow = yellow,
    yellow_light = yellow_light,
    yellow_lighter = yellow_lighter,
    amber_darker = amber_darker,
    amber_dark = amber_dark,
    amber = amber ,
    amber_light = amber_light,
    amber_lighter = amber_lighter,
    orange_darker = orange_darker,
    orange_dark = orange_dark,
    orange = orange,
    orange_light = orange_light,
    orange_lighter = orange_lighter,
    salmon_darker = salmon_darker,
    salmon_dark = salmon_dark,
    salmon = salmon,
    salmon_light = salmon_light ,
    salmon_lighter = salmon_lighter ,
    brown_darker = brown_darker,
    brown_dark = brown_dark,
    brown = brown ,
    brown_light = brown_light,
    brown_lighter = brown_lighter,
    grey_darker = grey_darker,
    grey_dark = grey_dark ,
    grey = grey,
    grey_light = grey_light,
    grey_lighter = grey_lighter,
    blue_grey_darker = blue_grey_darker ,
    blue_grey_dark = blue_grey_dark ,
    blue_grey = blue_grey ,
    blue_grey_light = blue_grey_light,
    blue_grey_lighter = blue_grey_lighter,
    black = black ,
    white = white ,
)


red_lighter         = "#FFEBEE"                    
red_light           = "#EF9A9A"                  
red                 = "#EF5350"             
red_dark            = "#E53935"                 
red_darker          = "#C62828"                   

pink_lighter        = "#FCE4EC"                     
pink_light          = "#F48FB1"                   
pink                = "#EC407A"             
pink_dark           = "#D81B60"                  
pink_darker         = "#AD1457"                    

purple_lighter      = "#F3E5F5"                       
purple_light        = "#CE93D8"                     
purple              = "#AB47BC"               
purple_dark         = "#8E24AA"                    
purple_darker       = "#6A1B9A"                      

deep_purple_lighter = "#EDE7F6"                            
deep_purple_light   = "#B39DDB"                          
deep_purple         = "#7E57C2"                    
deep_purple_dark    = "#5E35B1"                         
deep_purple_darker  = "#4527A0"                           

indigo_lighter      = "#E8EAF6"                       
indigo_light        = "#9FA8DA"                     
indigo              = "#5C6BC0"               
indigo_dark         = "#3949AB"                    
indigo_darker       = "#283593"                      

blue_lighter        = "#E3F2FD"                     
blue_light          = "#90CAF9"                   
blue                = "#42A5F5"             
blue_dark           = "#1E88E5"                  
blue_darker         = "#1565C0"                    

light_blue_lighter  = "#E1F5FE"                           
light_blue_light    = "#81D4FA"                         
light_blue          = "#29B6F6"                    
light_blue_dark     = "#039BE5"                        
light_blue_darker   = "#0277BD"                          

cyan_lighter        = "#E0F7FA"                     
cyan_light          = "#80DEEA"                   
cyan                = "#26C6DA"             
cyan_dark           = "#00ACC1"                  
cyan_darker         = "#00838F"                    

teal_lighter        = "#E0F2F1"                     
teal_light          = "#80CBC4"                   
teal                = "#26A69A"             
teal_dark           = "#00897B"                  
teal_darker         = "#00695C"                    

green_lighter       = "#E8F5E9"                      
green_light         = "#A5D6A7"                    
green               = "#66BB6A"  
green_dark          = "#43A047"                   
green_darker        = "#2E7D32"                     

light_green_lighter = "#F1F8E9"                            
light_green_light   = "#C5E1A5"                          
light_green         = "#9CCC65"                    
light_green_dark    = "#7CB342"                         
light_green_darker  = "#558B2F"                           

lime_lighter        = "#F9FBE7"                     
lime_light          = "#E6EE9C"                   
lime                = "#D4E157"             
lime_dark           = "#C0CA33"                  
lime_darker         = "#9E9D24"                    

yellow_lighter      = "#FFFDE7"                       
yellow_light        = "#FFF59D"                     
yellow              = "#FFEE58"               
yellow_dark         = "#FDD835"                    
yellow_darker       = "#F9A825"                      

amber_lighter       = "#FFF8E1"                      
amber_light         = "#FFE082"                    
amber               = "#FFCA28"  
amber_dark          = "#FFB300"                   
amber_darker        = "#FF8F00"                     

orange_lighter      = "#FFF3E0"                       
orange_light        = "#FFCC80"                     
orange              = "#FFA726"               
orange_dark         = "#FB8C00"                    
orange_darker       = "#EF6C00"                      

salmon_lighter      = "#FBE9E7"                            
salmon_light        = "#FFAB91"                          
salmon              = "#FF7043"                    
salmon_dark         = "#F4511E"                         
salmon_darker       = "#D84315"                           

brown_lighter       = "#EFEBE9"                      
brown_light         = "#BCAAA4"                    
brown               = "#8D6E63"  
brown_dark          = "#6D4C41"                   
brown_darker        = "#4E342E"                     

grey_lighter        = "#FAFAFA"                     
grey_light          = "#EEEEEE"                   
grey                = "#BDBDBD"             
grey_dark           = "#757575"                  
grey_darker         = "#424242"                    

blue_grey_lighter   = "#ECEFF1"                          
blue_grey_light     = "#B0BEC5"                        
blue_grey           = "#78909C"                    
blue_grey_dark      = "#546E7A"                       
blue_grey_darker    = "#37474F"                         


black               = "#000000"  
white               = "#FFFFFF"  




from .codes import (
    red_darker,
    red_dark,
    red,
    red_light,
    red_lighter,
    pink_darker,
    pink_dark,
    pink,
    pink_light,
    pink_lighter,
    purple_darker,
    purple_dark,
    purple,
    purple_light,
    purple_lighter,
    deep_purple_darker,
    deep_purple_dark,
    deep_purple,
    deep_purple_light,
    deep_purple_lighter,
    indigo_darker,
    indigo_dark,
    indigo,
    indigo_light,
    indigo_lighter,
    blue_darker,
    blue_dark,
    blue,
    blue_light,
    blue_lighter,
    light_blue_darker,
    light_blue_dark,
    light_blue,
    light_blue_light,
    light_blue_lighter,
    cyan_darker,
    cyan_dark,
    cyan,
    cyan_light,
    cyan_lighter,
    teal_darker,
    teal_dark,
    teal,
    teal_light,
    teal_lighter,
    green_darker,
    green_dark,
    green,
    green_light,
    green_lighter,
    light_green_darker,
    light_green_dark,
    light_green,
    light_green_light,
    light_green_lighter,
    lime_darker,
    lime_dark,
    lime,
    lime_light,
    lime_lighter,
    yellow_darker,
    yellow_dark,
    yellow,
    yellow_light,
    yellow_lighter,
    amber_darker,
    amber_dark,
    amber,
    amber_light,
    amber_lighter,
    orange_darker,
    orange_dark,
    orange,
    orange_light,
    orange_lighter,
    salmon_darker,
    salmon_dark,
    salmon,
    salmon_light,
    salmon_lighter,
    brown_darker,
    brown_dark,
    brown,
    brown_light,
    brown_lighter,
    grey_darker,
    grey_dark,
    grey,
    grey_light,
    grey_lighter,
    blue_grey_darker,
    blue_grey_dark,
    blue_grey,
    blue_grey_light,
    blue_grey_lighter,
    black,
    white,
)
